find_possible_distribution: Find a possible distribution.
Description
This function aims to find a possible distribution that would give rise to
the observed sample parameters. For that, you need to pass a list of parameters,
best created with set_parameters