find_possible_distributions: Find several possible distributions.
Description
This function aims to find several possible distribution that would give rise to
the observed sample parameters. For that, you need to pass a list of parameters,
created with set_parameters